@@ -35,9 +35,9 @@ Examples:
         learn.fit(..., callbacks=WandbCallback(learn, ...))
     ```
 """
-from pathlib import Path
 import random
 import sys
+from pathlib import Path
 from typing import Any, Optional
 
 if sys.version_info >= (3, 8):
@@ -47,6 +47,7 @@ else:
 
 import fastai  # type: ignore[import]
 from fastai.callbacks import TrackerCallback  # type: ignore[import]
+
 import wandb
 
 try:
@@ -179,7 +180,7 @@ class WandbCallback(TrackerCallback):
             if self.model_path.is_file():
                 with self.model_path.open("rb") as model_file:
                     self.learn.load(model_file, purge=False)
-                    print("Loaded best saved model from {}".format(self.model_path))
+                    print(f"Loaded best saved model from {self.model_path}")
 
     def _wandb_log_predictions(self) -> None:
         """Log prediction samples"""
@@ -202,7 +203,8 @@ class WandbCallback(TrackerCallback):
             if not pred[1].shape or pred[1].dim() == 1:
                 pred_log.append(
                     wandb.Image(
-                        x.data, caption=f"Ground Truth: {y}\nPrediction: {pred[0]}",
+                        x.data,
+                        caption=f"Ground Truth: {y}\nPrediction: {pred[0]}",
                     )
                 )
 
