@@ -8,7 +8,6 @@ from typing import Any, Optional
 import wandb
 import wandb.util
 
-
 TENSORBOARD_C_MODULE = "tensorflow.python.ops.gen_summary_ops"
 TENSORBOARD_X_MODULE = "tensorboardX.writer"
 TENSORFLOW_PY_MODULE = "tensorflow.python.summary.writer.writer"
@@ -85,7 +84,10 @@ def patch(
 
 
 def _patch_tensorflow2(
-    writer: Any, module: Any, save: bool = True, root_logdir: str = "",
+    writer: Any,
+    module: Any,
+    save: bool = True,
+    root_logdir: str = "",
 ) -> None:
     # This configures TensorFlow 2 style Tensorboard logging
     old_csfw_func = writer.create_summary_file_writer
@@ -109,7 +111,7 @@ def _patch_tensorflow2(
         # In this case, the generated logdir
         # is generated and ends with the hostname, update the root_logdir to match.
         hostname = socket.gethostname()
-        search = re.search(r"-\d+_{}".format(hostname), logdir)
+        search = re.search(rf"-\d+_{hostname}", logdir)
         if search:
             root_logdir_arg = logdir[: search.span()[1]]
         elif root_logdir is not None and not os.path.abspath(logdir).startswith(
@@ -130,7 +132,10 @@ def _patch_tensorflow2(
 
 
 def _patch_file_writer(
-    writer: Any, module: Any, save: bool = True, root_logdir: str = "",
+    writer: Any,
+    module: Any,
+    save: bool = True,
+    root_logdir: str = "",
 ) -> None:
     # This configures non-TensorFlow Tensorboard logging, or tensorflow <= 1.15
     logdir_hist = []
@@ -149,7 +154,7 @@ def _patch_file_writer(
             # In this case, the logdir is generated and ends with the hostname,
             # update the root_logdir to match.
             hostname = socket.gethostname()
-            search = re.search(r"-\d+_{}".format(hostname), logdir)
+            search = re.search(rf"-\d+_{hostname}", logdir)
             if search:
                 root_logdir_arg = logdir[: search.span()[1]]
 
@@ -164,7 +169,7 @@ def _patch_file_writer(
 
             _notify_tensorboard_logdir(logdir, save=save, root_logdir=root_logdir_arg)
 
-            super(TBXEventFileWriter, self).__init__(logdir, *args, **kwargs)
+            super().__init__(logdir, *args, **kwargs)
 
     writer.orig_EventFileWriter = writer.EventFileWriter
     writer.EventFileWriter = TBXEventFileWriter
