@@ -22,6 +22,7 @@ else:
 
 import wandb
 from wandb import util
+from wandb.sdk.lib import runid
 
 from . import _dtypes
 from ._private import MEDIA_TMP
@@ -33,7 +34,7 @@ if TYPE_CHECKING:  # pragma: no cover
     from ..wandb_artifacts import Artifact as LocalArtifact
     from ..wandb_run import Run as LocalRun
 
-    numeric = Union[int, float, np.integer, np.float]
+    numeric = Union[int, float, np.integer, np.float_]
     FileFormat3D = Literal[
         "obj",
         "gltf",
@@ -88,7 +89,7 @@ class Object3D(BatchableMedia):
     ```
     [[x y z],       ...] nx3
     [[x y z c],     ...] nx4 where c is a category with supported range [1, 14]
-    [[x y z r g b], ...] nx4 where is rgb is color
+    [[x y z r g b], ...] nx6 where is rgb is color
     ```
     """
 
@@ -112,12 +113,12 @@ class Object3D(BatchableMedia):
 
         if hasattr(data_or_path, "name"):
             # if the file has a path, we just detect the type and copy it from there
-            data_or_path = data_or_path.name  # type: ignore
+            data_or_path = data_or_path.name
 
         if hasattr(data_or_path, "read"):
             if hasattr(data_or_path, "seek"):
-                data_or_path.seek(0)  # type: ignore
-            object_3d = data_or_path.read()  # type: ignore
+                data_or_path.seek(0)
+            object_3d = data_or_path.read()
 
             extension = kwargs.pop("file_type", None)
             if extension is None:
@@ -132,7 +133,7 @@ class Object3D(BatchableMedia):
 
             extension = "." + extension
 
-            tmp_path = os.path.join(MEDIA_TMP.name, util.generate_id() + extension)
+            tmp_path = os.path.join(MEDIA_TMP.name, runid.generate_id() + extension)
             with open(tmp_path, "w") as f:
                 f.write(object_3d)
 
@@ -174,7 +175,7 @@ class Object3D(BatchableMedia):
                     "Type not supported, only 'lidar/beta' is currently supported"
                 )
 
-            tmp_path = os.path.join(MEDIA_TMP.name, util.generate_id() + ".pts.json")
+            tmp_path = os.path.join(MEDIA_TMP.name, runid.generate_id() + ".pts.json")
             with codecs.open(tmp_path, "w", encoding="utf-8") as fp:
                 json.dump(
                     data,
@@ -205,7 +206,7 @@ class Object3D(BatchableMedia):
                 )
 
             list_data = np_data.tolist()
-            tmp_path = os.path.join(MEDIA_TMP.name, util.generate_id() + ".pts.json")
+            tmp_path = os.path.join(MEDIA_TMP.name, runid.generate_id() + ".pts.json")
             with codecs.open(tmp_path, "w", encoding="utf-8") as fp:
                 json.dump(
                     list_data,
@@ -220,7 +221,9 @@ class Object3D(BatchableMedia):
 
     @classmethod
     def from_file(
-        cls, data_or_path: Union["TextIO", str], file_type: "FileFormat3D" = None
+        cls,
+        data_or_path: Union["TextIO", str],
+        file_type: Optional["FileFormat3D"] = None,
     ) -> "Object3D":
         # if file_type is not None and file_type not in cls.SUPPORTED_TYPES:
         #     raise ValueError(
