@@ -22,7 +22,7 @@ import threading
 import time
 import traceback
 from datetime import datetime
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, List, Optional
 
 import psutil
 
@@ -31,12 +31,11 @@ from wandb.util import sentry_exc, sentry_set_scope
 
 from ..interface.interface_queue import InterfaceQueue
 from ..lib import tracelog
-from . import handler, internal_util, sender, settings_static, writer
+from . import context, handler, internal_util, sender, settings_static, writer
 
 if TYPE_CHECKING:
     from queue import Queue
     from threading import Event
-    from typing import Any, List, Optional
 
     from wandb.proto.wandb_internal_pb2 import Record, Result
 
@@ -51,8 +50,8 @@ def wandb_internal(
     settings: "SettingsDict",
     record_q: "Queue[Record]",
     result_q: "Queue[Result]",
-    port: int = None,
-    user_pid: int = None,
+    port: Optional[int] = None,
+    user_pid: Optional[int] = None,
 ) -> None:
     """Internal process function entrypoint.
 
@@ -98,26 +97,33 @@ def wandb_internal(
     stopped = threading.Event()
     threads: "List[RecordLoopThread]" = []
 
+    context_keeper = context.ContextKeeper()
+
     send_record_q: "Queue[Record]" = queue.Queue()
     tracelog.annotate_queue(send_record_q, "send_q")
+
+    write_record_q: "Queue[Record]" = queue.Queue()
+    tracelog.annotate_queue(write_record_q, "write_q")
+
     record_sender_thread = SenderThread(
         settings=_settings,
         record_q=send_record_q,
         result_q=result_q,
         stopped=stopped,
         interface=publish_interface,
-        debounce_interval_ms=30000,
+        debounce_interval_ms=5000,
+        context_keeper=context_keeper,
     )
     threads.append(record_sender_thread)
 
-    write_record_q: "Queue[Record]" = queue.Queue()
-    tracelog.annotate_queue(write_record_q, "write_q")
     record_writer_thread = WriterThread(
         settings=_settings,
         record_q=write_record_q,
         result_q=result_q,
         stopped=stopped,
-        writer_q=write_record_q,
+        interface=publish_interface,
+        sender_q=send_record_q,
+        context_keeper=context_keeper,
     )
     threads.append(record_writer_thread)
 
@@ -126,9 +132,9 @@ def wandb_internal(
         record_q=record_q,
         result_q=result_q,
         stopped=stopped,
-        sender_q=send_record_q,
         writer_q=write_record_q,
         interface=publish_interface,
+        context_keeper=context_keeper,
     )
     threads.append(record_handler_thread)
 
@@ -157,6 +163,12 @@ def wandb_internal(
     for thread in threads:
         thread.join()
 
+    def close_internal_log() -> None:
+        root = logging.getLogger("wandb")
+        for _handler in root.handlers[:]:
+            _handler.close()
+            root.removeHandler(_handler)
+
     for thread in threads:
         exc_info = thread.get_exception()
         if exc_info:
@@ -171,6 +183,8 @@ def wandb_internal(
                 os._exit(-1)
             sys.exit(-1)
 
+    close_internal_log()
+
 
 def _setup_tracelog() -> None:
     # TODO: remove this temporary hack, need to find a better way to pass settings
@@ -180,7 +194,9 @@ def _setup_tracelog() -> None:
         tracelog.enable(tracelog_mode)
 
 
-def configure_logging(log_fname: str, log_level: int, run_id: str = None) -> None:
+def configure_logging(
+    log_fname: str, log_level: int, run_id: Optional[str] = None
+) -> None:
     # TODO: we may want make prints and stdout make it into the logs
     # sys.stdout = open(settings.log_internal, "a")
     # sys.stderr = open(settings.log_internal, "a")
@@ -221,6 +237,7 @@ class HandlerThread(internal_util.RecordLoopThread):
     _record_q: "Queue[Record]"
     _result_q: "Queue[Result]"
     _stopped: "Event"
+    _context_keeper: context.ContextKeeper
 
     def __init__(
         self,
@@ -228,9 +245,9 @@ class HandlerThread(internal_util.RecordLoopThread):
         record_q: "Queue[Record]",
         result_q: "Queue[Result]",
         stopped: "Event",
-        sender_q: "Queue[Record]",
         writer_q: "Queue[Record]",
         interface: "InterfaceQueue",
+        context_keeper: context.ContextKeeper,
         debounce_interval_ms: "float" = 1000,
     ) -> None:
         super().__init__(
@@ -244,9 +261,9 @@ class HandlerThread(internal_util.RecordLoopThread):
         self._record_q = record_q
         self._result_q = result_q
         self._stopped = stopped
-        self._sender_q = sender_q
         self._writer_q = writer_q
         self._interface = interface
+        self._context_keeper = context_keeper
 
     def _setup(self) -> None:
         self._hm = handler.HandleManager(
@@ -254,9 +271,9 @@ class HandlerThread(internal_util.RecordLoopThread):
             record_q=self._record_q,
             result_q=self._result_q,
             stopped=self._stopped,
-            sender_q=self._sender_q,
             writer_q=self._writer_q,
             interface=self._interface,
+            context_keeper=self._context_keeper,
         )
 
     def _process(self, record: "Record") -> None:
@@ -274,6 +291,7 @@ class SenderThread(internal_util.RecordLoopThread):
 
     _record_q: "Queue[Record]"
     _result_q: "Queue[Result]"
+    _context_keeper: context.ContextKeeper
 
     def __init__(
         self,
@@ -282,6 +300,7 @@ class SenderThread(internal_util.RecordLoopThread):
         result_q: "Queue[Result]",
         stopped: "Event",
         interface: "InterfaceQueue",
+        context_keeper: context.ContextKeeper,
         debounce_interval_ms: "float" = 5000,
     ) -> None:
         super().__init__(
@@ -295,6 +314,7 @@ class SenderThread(internal_util.RecordLoopThread):
         self._record_q = record_q
         self._result_q = result_q
         self._interface = interface
+        self._context_keeper = context_keeper
 
     def _setup(self) -> None:
         self._sm = sender.SendManager(
@@ -302,6 +322,7 @@ class SenderThread(internal_util.RecordLoopThread):
             record_q=self._record_q,
             result_q=self._result_q,
             interface=self._interface,
+            context_keeper=self._context_keeper,
         )
 
     def _process(self, record: "Record") -> None:
@@ -319,6 +340,7 @@ class WriterThread(internal_util.RecordLoopThread):
 
     _record_q: "Queue[Record]"
     _result_q: "Queue[Result]"
+    _context_keeper: context.ContextKeeper
 
     def __init__(
         self,
@@ -326,11 +348,13 @@ class WriterThread(internal_util.RecordLoopThread):
         record_q: "Queue[Record]",
         result_q: "Queue[Result]",
         stopped: "Event",
-        writer_q: "Queue[Record]",
+        interface: "InterfaceQueue",
+        sender_q: "Queue[Record]",
+        context_keeper: context.ContextKeeper,
         debounce_interval_ms: "float" = 1000,
     ) -> None:
         super().__init__(
-            input_record_q=writer_q,
+            input_record_q=record_q,
             result_q=result_q,
             stopped=stopped,
             debounce_interval_ms=debounce_interval_ms,
@@ -339,12 +363,18 @@ class WriterThread(internal_util.RecordLoopThread):
         self._settings = settings
         self._record_q = record_q
         self._result_q = result_q
+        self._sender_q = sender_q
+        self._interface = interface
+        self._context_keeper = context_keeper
 
     def _setup(self) -> None:
         self._wm = writer.WriteManager(
             settings=self._settings,
             record_q=self._record_q,
             result_q=self._result_q,
+            sender_q=self._sender_q,
+            interface=self._interface,
+            context_keeper=self._context_keeper,
         )
 
     def _process(self, record: "Record") -> None:
@@ -360,9 +390,9 @@ class WriterThread(internal_util.RecordLoopThread):
 class ProcessCheck:
     """Class to help watch a process id to detect when it is dead."""
 
-    check_process_last: "Optional[float]"
+    check_process_last: Optional[float]
 
-    def __init__(self, settings: "SettingsStatic", user_pid: "Optional[int]") -> None:
+    def __init__(self, settings: "SettingsStatic", user_pid: Optional[int]) -> None:
         self.settings = settings
         self.pid = user_pid
         self.check_process_last = None
