@@ -1,21 +1,28 @@
-import json
 import pprint
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional
 
 import wandb
 import wandb.apis.public as public
 from wandb.apis.internal import Api
 from wandb.errors import LaunchError
+from wandb.sdk.launch._project_spec import (
+    compute_command_args,
+    create_project_from_spec,
+)
+from wandb.sdk.launch.builder.build import build_image_from_project
 from wandb.sdk.launch.utils import (
+    LAUNCH_DEFAULT_PROJECT,
     LOG_PREFIX,
     construct_launch_spec,
     validate_launch_spec_source,
 )
 
 
-def push_to_queue(api: Api, queue_name: str, launch_spec: Dict[str, Any]) -> Any:
+def push_to_queue(
+    api: Api, queue_name: str, launch_spec: Dict[str, Any], project_queue: str
+) -> Any:
     try:
-        res = api.push_to_run_queue(queue_name, launch_spec)
+        res = api.push_to_run_queue(queue_name, launch_spec, project_queue)
     except Exception as e:
         wandb.termwarn(f"{LOG_PREFIX}Exception when pushing to queue {e}")
         return None
@@ -25,7 +32,7 @@ def push_to_queue(api: Api, queue_name: str, launch_spec: Dict[str, Any]) -> Any
 def launch_add(
     uri: Optional[str] = None,
     job: Optional[str] = None,
-    config: Optional[Union[str, Dict[str, Any]]] = None,
+    config: Optional[Dict[str, Any]] = None,
     project: Optional[str] = None,
     entity: Optional[str] = None,
     queue_name: Optional[str] = None,
@@ -35,9 +42,12 @@ def launch_add(
     version: Optional[str] = None,
     docker_image: Optional[str] = None,
     params: Optional[Dict[str, Any]] = None,
+    project_queue: Optional[str] = None,
     resource_args: Optional[Dict[str, Any]] = None,
     cuda: Optional[bool] = None,
     run_id: Optional[str] = None,
+    build: Optional[bool] = False,
+    repository: Optional[str] = None,
 ) -> "public.QueuedRun":
     """Enqueue a W&B launch experiment. With either a source uri, job or docker_image.
 
@@ -49,7 +59,7 @@ def launch_add(
     project: Target project to send launched run to
     entity: Target entity to send launched run to
     queue: the name of the queue to enqueue the run to
-    resource: Execution backend for the run: W&B provides built-in support for "local" backend
+    resource: Execution backend for the run: W&B provides built-in support for "local-container" backend
     entry_point: Entry point to run within the project. Defaults to using the entry point used
         in the original run for wandb URIs, or main.py for git repository URIs.
     name: Name run under which to launch the run.
@@ -61,6 +71,13 @@ def launch_add(
         Will be stored on the constructed launch config under ``resource_args``.
     cuda: Whether to build a CUDA-enabled docker image or not
     run_id: optional string indicating the id of the launched run
+    build: optional flag defaulting to false, requires queue to be set
+        if build, an image is created, creates a job artifact, pushes a reference
+            to that job artifact to queue
+    repository: optional string to control the name of the remote repository, used when
+        pushing images to a registry
+    project_queue: optional string to control the name of the project for the queue. Primarily used
+        for back compatibility with project scoped queues
 
 
     Example:
@@ -97,9 +114,12 @@ def launch_add(
         version,
         docker_image,
         params,
+        project_queue,
         resource_args,
         cuda,
         run_id=run_id,
+        build=build,
+        repository=repository,
     )
 
 
@@ -107,7 +127,7 @@ def _launch_add(
     api: Api,
     uri: Optional[str],
     job: Optional[str],
-    config: Optional[Union[str, Dict[str, Any]]],
+    config: Optional[Dict[str, Any]],
     project: Optional[str],
     entity: Optional[str],
     queue_name: Optional[str],
@@ -117,24 +137,13 @@ def _launch_add(
     version: Optional[str],
     docker_image: Optional[str],
     params: Optional[Dict[str, Any]],
+    project_queue: Optional[str],
     resource_args: Optional[Dict[str, Any]] = None,
     cuda: Optional[bool] = None,
     run_id: Optional[str] = None,
+    build: Optional[bool] = False,
+    repository: Optional[str] = None,
 ) -> "public.QueuedRun":
-
-    resource = resource or "local"
-    if config is not None:
-        if isinstance(config, str):
-            with open(config) as fp:
-                launch_config = json.load(fp)
-        elif isinstance(config, dict):
-            launch_config = config
-    else:
-        launch_config = {}
-
-    if queue_name is None:
-        queue_name = "default"
-
     launch_spec = construct_launch_spec(
         uri,
         job,
@@ -148,20 +157,59 @@ def _launch_add(
         version,
         params,
         resource_args,
-        launch_config,
+        config,
         cuda,
         run_id,
+        repository,
     )
+
+    if build:
+        if resource == "local-process":
+            raise LaunchError(
+                "Cannot build a docker image for the resource: local-process"
+            )
+
+        if launch_spec.get("job") is not None:
+            wandb.termwarn("Build doesn't support setting a job. Overwriting job.")
+            launch_spec["job"] = None
+
+        launch_project = create_project_from_spec(launch_spec, api)
+        docker_image_uri = build_image_from_project(launch_project, api, config)
+        run = wandb.run or wandb.init(
+            project=launch_spec["project"],
+            entity=launch_spec["entity"],
+            job_type="launch_job",
+        )
+
+        args = compute_command_args(launch_project.override_args)
+        job_artifact = run._log_job_artifact_with_image(docker_image_uri, args)
+        job_name = job_artifact.wait().name
+
+        job = f"{launch_spec['entity']}/{launch_spec['project']}/{job_name}"
+        launch_spec["job"] = job
+        launch_spec["uri"] = None  # Remove given URI --> now in job
+
+    if queue_name is None:
+        queue_name = "default"
+    if project_queue is None:
+        project_queue = LAUNCH_DEFAULT_PROJECT
+
     validate_launch_spec_source(launch_spec)
-    res = push_to_queue(api, queue_name, launch_spec)
+    res = push_to_queue(api, queue_name, launch_spec, project_queue)
 
     if res is None or "runQueueItemId" not in res:
         raise LaunchError("Error adding run to queue")
-    wandb.termlog(f"{LOG_PREFIX}Added run to queue {queue_name}.")
+
+    updated_spec = res.get("runSpec")
+    if updated_spec:
+        if updated_spec.get("resource_args"):
+            launch_spec["resource_args"] = updated_spec.get("resource_args")
+        if updated_spec.get("resource"):
+            launch_spec["resource"] = updated_spec.get("resource")
+
+    wandb.termlog(f"{LOG_PREFIX}Added run to queue {project_queue}/{queue_name}.")
     wandb.termlog(f"{LOG_PREFIX}Launch spec:\n{pprint.pformat(launch_spec)}\n")
     public_api = public.Api()
-    queued_run_entity = launch_spec.get("entity")
-    queued_run_project = launch_spec.get("project")
     container_job = False
     if job:
         job_artifact = public_api.job(job)
@@ -169,10 +217,11 @@ def _launch_add(
             container_job = True
 
     queued_run = public_api.queued_run(
-        queued_run_entity,
-        queued_run_project,
+        launch_spec["entity"],
+        launch_spec["project"],
         queue_name,
         res["runQueueItemId"],
         container_job,
+        project_queue,
     )
     return queued_run  # type: ignore
