@@ -70,10 +70,13 @@ class LocalProcessRunner(AbstractRunner):
             )
         elif launch_project.job:
             assert launch_project._job_artifact is not None
-            validate_wandb_python_deps(
-                "requirements.frozen.txt",
-                launch_project.project_dir,
-            )
+            try:
+                validate_wandb_python_deps(
+                    "requirements.frozen.txt",
+                    launch_project.project_dir,
+                )
+            except Exception:
+                wandb.termwarn("Unable to validate python dependencies")
         env_vars = get_env_vars_dict(launch_project, self._api)
         for env_key, env_value in env_vars.items():
             cmd += [f"{shlex.quote(env_key)}={shlex.quote(env_value)}"]
