@@ -69,7 +69,7 @@ def dict_no_value_from_proto_list(obj_list):
         if not isinstance(possible_dict, dict) or "value" not in possible_dict:
             # (tss) TODO: This is protecting against legacy 'wandb_version' field.
             # Should investigate why the config payload even has 'wandb_version'.
-            logger.warning(f"key '{item.key}' has no 'value' attribute")
+            logger.warning(f"key {item.key!r} has no 'value' attribute")
             continue
         d[item.key] = possible_dict["value"]
 
