@@ -4,13 +4,12 @@ from typing import Optional
 
 import wandb
 
-
 logger = logging.getLogger(__name__)
 
 
 TABLE_STYLES = """<style>
-    table.wandb td:nth-child(1) { padding: 0 10px; text-align: right }
-    .wandb-row { display: flex; flex-direction: row; flex-wrap: wrap; width: 100% }
+    table.wandb td:nth-child(1) { padding: 0 10px; text-align: left ; width: auto;} td:nth-child(2) {text-align: left ; width: 100%}
+    .wandb-row { display: flex; flex-direction: row; flex-wrap: wrap; justify-content: flex-start; width: 100% }
     .wandb-col { display: flex; flex-direction: column; flex-basis: 100%; flex: 1; padding: 10px; }
     </style>
 """
@@ -44,7 +43,7 @@ def display_html(html: str):  # type: ignore
     if wandb.run and wandb.run._settings.silent:
         return
     try:
-        from IPython.core.display import display, HTML  # type: ignore
+        from IPython.core.display import HTML, display  # type: ignore
     except ImportError:
         wandb.termwarn("Unable to render HTML, can't import display from ipython.core")
         return False
