@@ -1,3 +1,5 @@
+import abc
+import asyncio
 import datetime
 import functools
 import logging
@@ -5,7 +7,7 @@ import os
 import random
 import threading
 import time
-from typing import Any, Callable, Generic, Optional, Tuple, Type, TypeVar
+from typing import Any, Awaitable, Callable, Generic, Optional, Tuple, Type, TypeVar
 
 from requests import HTTPError
 
@@ -20,6 +22,7 @@ logger = logging.getLogger(__name__)
 # should only use these variables, not call the stdlib funcs directly.
 NOW_FN = datetime.datetime.now
 SLEEP_FN = time.sleep
+SLEEP_ASYNC_FN = asyncio.sleep
 
 
 class TransientError(Exception):
@@ -211,3 +214,76 @@ def retriable(*args: Any, **kargs: Any) -> Callable[[_F], _F]:
         return wrapped_fn  # type: ignore
 
     return decorator
+
+
+class Backoff(abc.ABC):
+    """A backoff strategy: decides whether to sleep or give up when an exception is raised."""
+
+    @abc.abstractmethod
+    def next_sleep_or_reraise(self, exc: Exception) -> datetime.timedelta:
+        raise NotImplementedError  # pragma: no cover
+
+
+class ExponentialBackoff(Backoff):
+    """Jittered exponential backoff: sleep times increase ~exponentially up to some limit."""
+
+    def __init__(
+        self,
+        initial_sleep: datetime.timedelta,
+        max_sleep: datetime.timedelta,
+        max_retries: Optional[int] = None,
+        timeout_at: Optional[datetime.datetime] = None,
+    ) -> None:
+        self._next_sleep = min(max_sleep, initial_sleep)
+        self._max_sleep = max_sleep
+        self._remaining_retries = max_retries
+        self._timeout_at = timeout_at
+
+    def next_sleep_or_reraise(self, exc: Exception) -> datetime.timedelta:
+        if self._remaining_retries is not None:
+            if self._remaining_retries <= 0:
+                raise exc
+            self._remaining_retries -= 1
+
+        if self._timeout_at is not None and NOW_FN() > self._timeout_at:
+            raise exc
+
+        result, self._next_sleep = self._next_sleep, min(
+            self._max_sleep, self._next_sleep * (1 + random.random())
+        )
+
+        return result
+
+
+class FilteredBackoff(Backoff):
+    """Re-raise any exceptions that fail a predicate; delegate others to another Backoff."""
+
+    def __init__(self, filter: Callable[[Exception], bool], wrapped: Backoff) -> None:
+        self._filter = filter
+        self._wrapped = wrapped
+
+    def next_sleep_or_reraise(self, exc: Exception) -> datetime.timedelta:
+        if not self._filter(exc):
+            raise exc
+        return self._wrapped.next_sleep_or_reraise(exc)
+
+
+async def retry_async(
+    backoff: Backoff,
+    fn: Callable[..., Awaitable[_R]],
+    *args: Any,
+    on_exc: Optional[Callable[[Exception], None]] = None,
+    **kwargs: Any,
+) -> _R:
+    """Call `fn` repeatedly until either it succeeds, or `backoff` decides we should give up.
+
+    Each time `fn` fails, `on_exc` is called with the exception.
+    """
+
+    while True:
+        try:
+            return await fn(*args, **kwargs)
+        except Exception as e:
+            if on_exc is not None:
+                on_exc(e)
+            await SLEEP_ASYNC_FN(backoff.next_sleep_or_reraise(e).total_seconds())
