@@ -16,7 +16,7 @@ import platform
 import sys
 import tempfile
 import traceback
-from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
 
 import wandb
 import wandb.env
@@ -39,8 +39,8 @@ from .lib import (
     telemetry,
 )
 from .lib.deprecate import Deprecated, deprecate
-from .lib.mailbox import Mailbox, MailboxHandle
-from .lib.printer import get_printer
+from .lib.mailbox import Mailbox, MailboxHandle, MailboxProgress
+from .lib.printer import Printer, get_printer
 from .lib.wburls import wburls
 from .wandb_helper import parse_config
 from .wandb_run import Run, TeardownHook, TeardownStage
@@ -49,24 +49,20 @@ from .wandb_settings import Settings, Source
 if TYPE_CHECKING:
     from wandb.proto import wandb_internal_pb2 as pb
 
-logger = None  # logger configured during wandb.init()
+logger: Optional[logging.Logger] = None  # logger configured during wandb.init()
 
 
-def _set_logger(log_object):
+def _set_logger(log_object: logging.Logger) -> None:
     """Configure module logger."""
     global logger
     logger = log_object
 
 
-def online_status(*args, **kwargs):
-    pass
-
-
-def _huggingface_version():
+def _huggingface_version() -> Optional[str]:
     if "transformers" in sys.modules:
         trans = wandb.util.get_module("transformers")
         if hasattr(trans, "__version__"):
-            return trans.__version__
+            return str(trans.__version__)
     return None
 
 
@@ -85,7 +81,7 @@ def _maybe_mp_process(backend: Backend) -> bool:
 
 
 def _handle_launch_config(settings: "Settings") -> Dict[str, Any]:
-    launch_run_config = {}
+    launch_run_config: Dict[str, Any] = {}
     if not settings.launch:
         return launch_run_config
     if os.environ.get("WANDB_CONFIG") is not None:
@@ -103,20 +99,20 @@ def _handle_launch_config(settings: "Settings") -> Dict[str, Any]:
 class _WandbInit:
     _init_telemetry_obj: telemetry.TelemetryRecord
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.kwargs = None
-        self.settings = None
-        self.sweep_config = None
-        self.launch_config = {}
-        self.config = None
-        self.run = None
-        self.backend = None
+        self.settings: Optional[Settings] = None
+        self.sweep_config: Dict[str, Any] = {}
+        self.launch_config: Dict[str, Any] = {}
+        self.config: Dict[str, Any] = {}
+        self.run: Optional[Run] = None
+        self.backend: Optional[Backend] = None
 
-        self._teardown_hooks = []
-        self._wl = None
-        self._reporter = None
-        self.notebook = None
-        self.printer = None
+        self._teardown_hooks: List[TeardownHook] = []
+        self._wl: Optional[wandb_setup._WandbSetup] = None
+        self._reporter: Optional[wandb.sdk.lib.reporting.Reporter] = None
+        self.notebook: Optional["wandb.jupyter.Notebook"] = None  # type: ignore
+        self.printer: Optional[Printer] = None
 
         self._init_telemetry_obj = telemetry.TelemetryRecord()
 
@@ -127,7 +123,7 @@ class _WandbInit:
             return
         self.printer = get_printer(settings._jupyter)
 
-    def setup(self, kwargs) -> None:  # noqa: C901
+    def setup(self, kwargs: Any) -> None:  # noqa: C901
         """Completes setup for `wandb.init()`.
 
         This includes parsing all arguments, applying them with settings and enabling logging.
@@ -140,6 +136,7 @@ class _WandbInit:
         singleton = wandb_setup._WandbSetup._instance
         if singleton is not None:
             self._setup_printer(settings=singleton._settings)
+            assert self.printer
             exclude_env_vars = {"WANDB_SERVICE", "WANDB_KUBEFLOW_URL"}
             # check if environment variables have changed
             singleton_env = {
@@ -166,6 +163,7 @@ class _WandbInit:
 
         self._wl = wandb_setup.setup()
         # Make sure we have a logger setup (might be an early logger)
+        assert self._wl is not None
         _set_logger(self._wl._get_logger())
 
         # Start with settings from wandb library singleton
@@ -228,7 +226,7 @@ class _WandbInit:
         self.sweep_config = dict()
         sweep_config = self._wl._sweep_config or dict()
         self.config = dict()
-        self.init_artifact_config = dict()
+        self.init_artifact_config: Dict[str, Any] = dict()
         for config_data in (
             sagemaker_config,
             self._wl._config,
@@ -313,21 +311,24 @@ class _WandbInit:
 
         # self.settings.freeze()
 
-    def teardown(self):
+    def teardown(self) -> None:
         # TODO: currently this is only called on failed wandb.init attempts
         # normally this happens on the run object
+        assert logger
         logger.info("tearing down wandb.init")
         for hook in self._teardown_hooks:
             hook.call()
 
-    def _split_artifacts_from_config(self, config_source, config_target):
+    def _split_artifacts_from_config(
+        self, config_source: dict, config_target: dict
+    ) -> None:
         for k, v in config_source.items():
             if _is_artifact_representation(v):
                 self.init_artifact_config[k] = v
             else:
                 config_target.setdefault(k, v)
 
-    def _enable_logging(self, log_fname, run_id=None):
+    def _enable_logging(self, log_fname: str, run_id: Optional[str] = None) -> None:
         """Enables logging to the global debug log.
 
         This adds a run_id to the log, in case of multiple processes on the same machine.
@@ -337,7 +338,7 @@ class _WandbInit:
         handler.setLevel(logging.INFO)
 
         class WBFilter(logging.Filter):
-            def filter(self, record):
+            def filter(self, record: logging.LogRecord) -> bool:
                 record.run_id = run_id
                 return True
 
@@ -355,18 +356,21 @@ class _WandbInit:
         handler.setFormatter(formatter)
         if run_id:
             handler.addFilter(WBFilter())
+        assert logger is not None
         logger.propagate = False
         logger.addHandler(handler)
         # TODO: make me configurable
         logger.setLevel(logging.DEBUG)
         self._teardown_hooks.append(
             TeardownHook(
-                lambda: (handler.close(), logger.removeHandler(handler)),
+                lambda: (handler.close(), logger.removeHandler(handler)),  # type: ignore
                 TeardownStage.LATE,
             )
         )
 
-    def _safe_symlink(self, base, target, name, delete=False):
+    def _safe_symlink(
+        self, base: str, target: str, name: str, delete: bool = False
+    ) -> None:
         # TODO(jhr): do this with relpaths, but i cant figure it out on no sleep
         if not hasattr(os, "symlink"):
             return
@@ -386,28 +390,34 @@ class _WandbInit:
         except OSError:
             pass
 
-    def _pause_backend(self):
-        if self.backend is not None:
-            logger.info("pausing backend")
-            # Attempt to save the code on every execution
-            if self.notebook.save_ipynb():
-                res = self.run.log_code(root=None)
-                logger.info("saved code: %s", res)
+    def _pause_backend(self) -> None:
+        if self.backend is None:
+            return None
+
+        # Attempt to save the code on every execution
+        if self.notebook.save_ipynb():  # type: ignore
+            assert self.run is not None
+            res = self.run.log_code(root=None)
+            logger.info("saved code: %s", res)  # type: ignore
+        if self.backend.interface is not None:
+            logger.info("pausing backend")  # type: ignore
             self.backend.interface.publish_pause()
 
-    def _resume_backend(self):
-        if self.backend is not None:
-            logger.info("resuming backend")
+    def _resume_backend(self) -> None:
+        if self.backend is not None and self.backend.interface is not None:
+            logger.info("resuming backend")  # type: ignore
             self.backend.interface.publish_resume()
 
-    def _jupyter_teardown(self):
+    def _jupyter_teardown(self) -> None:
         """Teardown hooks and display saving, called with wandb.finish."""
+        assert self.notebook
         ipython = self.notebook.shell
         self.notebook.save_history()
         if self.notebook.save_ipynb():
+            assert self.run is not None
             res = self.run.log_code(root=None)
-            logger.info("saved code and history: %s", res)
-        logger.info("cleaning up jupyter logic")
+            logger.info("saved code and history: %s", res)  # type: ignore
+        logger.info("cleaning up jupyter logic")  # type: ignore
         # because of how we bind our methods we manually find them to unregister
         for hook in ipython.events.callbacks["pre_run_cell"]:
             if "_resume_backend" in hook.__name__:
@@ -418,14 +428,14 @@ class _WandbInit:
         ipython.display_pub.publish = ipython.display_pub._orig_publish
         del ipython.display_pub._orig_publish
 
-    def _jupyter_setup(self, settings):
+    def _jupyter_setup(self, settings: Settings) -> None:
         """Add hooks, and session history saving."""
         self.notebook = wandb.jupyter.Notebook(settings)
         ipython = self.notebook.shell
 
         # Monkey patch ipython publish to capture displayed outputs
         if not hasattr(ipython.display_pub, "_orig_publish"):
-            logger.info("configuring jupyter hooks %s", self)
+            logger.info("configuring jupyter hooks %s", self)  # type: ignore
             ipython.display_pub._orig_publish = ipython.display_pub.publish
             # Registering resume and pause hooks
 
@@ -435,15 +445,16 @@ class _WandbInit:
                 TeardownHook(self._jupyter_teardown, TeardownStage.EARLY)
             )
 
-        def publish(data, metadata=None, **kwargs):
+        def publish(data, metadata=None, **kwargs) -> None:  # type: ignore
             ipython.display_pub._orig_publish(data, metadata=metadata, **kwargs)
+            assert self.notebook is not None
             self.notebook.save_display(
                 ipython.execution_count, {"data": data, "metadata": metadata}
             )
 
         ipython.display_pub.publish = publish
 
-    def _log_setup(self, settings):
+    def _log_setup(self, settings: Settings) -> None:
         """Sets up logging from settings."""
         filesystem.mkdir_exists_ok(os.path.dirname(settings.log_user))
         filesystem.mkdir_exists_ok(os.path.dirname(settings.log_internal))
@@ -474,6 +485,9 @@ class _WandbInit:
         _set_logger(logging.getLogger("wandb"))
         self._enable_logging(settings.log_user)
 
+        assert self._wl
+        assert logger
+
         self._wl._early_logger_flush(logger)
         logger.info(f"Logging user logs to {settings.log_user}")
         logger.info(f"Logging internal logs to {settings.log_internal}")
@@ -506,7 +520,7 @@ class _WandbInit:
         )
         return drun
 
-    def _on_progress_init(self, handle: MailboxHandle) -> None:
+    def _on_progress_init(self, handle: MailboxProgress) -> None:
         assert self.printer
         line = "Waiting for wandb.init()...\r"
         percent_done = handle.percent_done
@@ -516,7 +530,10 @@ class _WandbInit:
         if logger is None:
             raise RuntimeError("Logger not initialized")
         logger.info("calling init triggers")
-        trigger.call("on_init", **self.kwargs)
+        trigger.call("on_init", **self.kwargs)  # type: ignore
+
+        assert self.settings
+        assert self._wl
 
         logger.info(
             f"wandb.init called with sweep_config: {self.sweep_config}\nconfig: {self.config}"
@@ -671,7 +688,7 @@ class _WandbInit:
 
         run._set_library(self._wl)
         run._set_backend(backend)
-        run._set_reporter(self._reporter)
+        run._set_reporter(self._reporter)  # type: ignore
         run._set_teardown_hooks(self._teardown_hooks)
         # TODO: pass mode to backend
         # run_synced = None
@@ -689,7 +706,7 @@ class _WandbInit:
 
         run_proto = backend.interface._make_run(run)
         run_init_handle: Optional[MailboxHandle] = None
-        run_result: Optional["pb.Result"] = None
+        run_result: Optional["pb.RunUpdateResult"] = None
 
         if self.settings._offline:
             with telemetry.context(run=run) as tel:
@@ -769,8 +786,9 @@ class _WandbInit:
         # TODO: add progress to let user know we are doing something
         run_start_result = run_start_handle.wait(timeout=30)
         if run_start_result is None:
-            run_start_handle.release()
+            run_start_handle.abandon()
 
+        assert self._wl is not None
         self._wl._global_run_stack.append(run)
         self.run = run
 
@@ -793,16 +811,17 @@ class _WandbInit:
             run.use_artifact(job_artifact)
 
         self.backend = backend
+        assert self._reporter
         self._reporter.set_context(run=run)
         run._on_start()
         logger.info("run started, returning control to user process")
         return run
 
 
-def getcaller():
-    # py2 doesnt have stack_info
-    # src, line, func, stack = logger.findCaller(stack_info=True)
-    src, line, func = logger.findCaller()[:3]
+def getcaller() -> None:
+    if not logger:
+        return None
+    src, line, func, stack = logger.findCaller(stack_info=True)
     print("Problem at:", src, line, func)
 
 
@@ -824,7 +843,7 @@ def _attach(
     if not ((attach_id is None) ^ (run is None)):
         raise UsageError("Either (`attach_id` or `run_id`) or `run` must be specified")
 
-    attach_id = attach_id or run._attach_id
+    attach_id = attach_id or (run._attach_id if run else None)
 
     if attach_id is None:
         raise UsageError(
@@ -833,6 +852,7 @@ def _attach(
     wandb._assert_is_user_process()
 
     _wl = wandb_setup._setup()
+    assert _wl
 
     _set_logger(_wl._get_logger())
     if logger is None:
@@ -869,12 +889,16 @@ def _attach(
     assert backend.interface
 
     mailbox.enable_keepalive()
-    resp = backend.interface.communicate_attach(attach_id)
-    if not resp:
-        raise UsageError("problem")
-    if resp and resp.error and resp.error.message:
-        raise UsageError(f"bad: {resp.error.message}")
-    run._set_run_obj(resp.run)
+    attach_handle = backend.interface.deliver_attach(attach_id)
+    # TODO: add progress to let user know we are doing something
+    attach_result = attach_handle.wait(timeout=30)
+    if not attach_result:
+        attach_handle.abandon()
+        raise UsageError("Timeout attaching to run")
+    attach_response = attach_result.response.attach_response
+    if attach_response.error and attach_response.error.message:
+        raise UsageError(f"Failed to attach to run: {attach_response.error.message}")
+    run._set_run_obj(attach_response.run)
     run._on_attach()
     return run
 
@@ -891,18 +915,18 @@ def init(
     name: Optional[str] = None,
     notes: Optional[str] = None,
     magic: Optional[Union[dict, str, bool]] = None,
-    config_exclude_keys=None,
-    config_include_keys=None,
+    config_exclude_keys: Optional[List[str]] = None,
+    config_include_keys: Optional[List[str]] = None,
     anonymous: Optional[str] = None,
     mode: Optional[str] = None,
     allow_val_change: Optional[bool] = None,
     resume: Optional[Union[bool, str]] = None,
     force: Optional[bool] = None,
-    tensorboard=None,  # alias for sync_tensorboard
-    sync_tensorboard=None,
-    monitor_gym=None,
-    save_code=None,
-    id=None,
+    tensorboard: Optional[bool] = None,  # alias for sync_tensorboard
+    sync_tensorboard: Optional[bool] = None,
+    monitor_gym: Optional[bool] = None,
+    save_code: Optional[bool] = None,
+    id: Optional[str] = None,
     settings: Union[Settings, Dict[str, Any], None] = None,
 ) -> Union[Run, RunDisabled, None]:
     r"""Starts a new run to track and log to W&B.
@@ -1103,6 +1127,7 @@ def init(
     try:
         wi = _WandbInit()
         wi.setup(kwargs)
+        assert wi.settings
         except_exit = wi.settings._except_exit
         try:
             run = wi.init()
