@@ -344,7 +344,7 @@ class Property:
         self.__dict__[key] = value
 
     def __str__(self) -> str:
-        return f"'{self.value}'" if isinstance(self.value, str) else f"{self.value}"
+        return f"{self.value!r}" if isinstance(self.value, str) else f"{self.value}"
 
     def __repr__(self) -> str:
         return (
@@ -412,7 +412,6 @@ class Settings:
     anonymous: str
     api_key: str
     base_url: str  # The base url for the wandb api
-    cache_dir: str  # The directory to use for artifacts cache: <cache_dir>/artifacts
     code_dir: str
     config_paths: Sequence[str]
     console: str
@@ -420,6 +419,7 @@ class Settings:
     disable_code: bool
     disable_git: bool
     disable_hints: bool
+    disable_job_creation: bool
     disabled: bool  # Alias for mode=dryrun, not supported yet
     docker: str
     email: str
@@ -570,6 +570,7 @@ class Settings:
             disable_code={"preprocessor": _str_as_bool},
             disable_hints={"preprocessor": _str_as_bool},
             disable_git={"preprocessor": _str_as_bool},
+            disable_job_creation={"value": False, "preprocessor": _str_as_bool},
             disabled={"value": False, "preprocessor": _str_as_bool},
             files_dir={
                 "value": "files",
@@ -747,7 +748,7 @@ class Settings:
     def _validate_mode(value: str) -> bool:
         choices: Set[str] = {"dryrun", "run", "offline", "online", "disabled"}
         if value not in choices:
-            raise UsageError(f"Settings field `mode`: '{value}' not in {choices}")
+            raise UsageError(f"Settings field `mode`: {value!r} not in {choices}")
         return True
 
     @staticmethod
@@ -756,14 +757,14 @@ class Settings:
         if value is not None:
             if len(value) > 128:
                 raise UsageError(
-                    f'Invalid project name "{value}": exceeded 128 characters'
+                    f"Invalid project name {value!r}: exceeded 128 characters"
                 )
             invalid_chars = {char for char in invalid_chars_list if char in value}
             if invalid_chars:
                 raise UsageError(
-                    f'Invalid project name "{value}": '
-                    f"cannot contain characters \"{','.join(invalid_chars_list)}\", "
-                    f"found \"{','.join(invalid_chars)}\""
+                    f"Invalid project name {value!r}: "
+                    f"cannot contain characters {','.join(invalid_chars_list)!r}, "
+                    f"found {','.join(invalid_chars)!r}"
                 )
         return True
 
@@ -774,7 +775,7 @@ class Settings:
             available_methods += multiprocessing.get_all_start_methods()
         if value not in available_methods:
             raise UsageError(
-                f"Settings field `start_method`: '{value}' not in {available_methods}"
+                f"Settings field `start_method`: {value!r} not in {available_methods}"
             )
         return True
 
@@ -793,21 +794,21 @@ class Settings:
         if value not in choices:
             # do not advertise internal console states
             choices -= {"wrap_emu", "wrap_raw"}
-            raise UsageError(f"Settings field `console`: '{value}' not in {choices}")
+            raise UsageError(f"Settings field `console`: {value!r} not in {choices}")
         return True
 
     @staticmethod
     def _validate_problem(value: str) -> bool:
         choices: Set[str] = {"fatal", "warn", "silent"}
         if value not in choices:
-            raise UsageError(f"Settings field `problem`: '{value}' not in {choices}")
+            raise UsageError(f"Settings field `problem`: {value!r} not in {choices}")
         return True
 
     @staticmethod
     def _validate_anonymous(value: str) -> bool:
         choices: Set[str] = {"allow", "must", "never", "false", "true"}
         if value not in choices:
-            raise UsageError(f"Settings field `anonymous`: '{value}' not in {choices}")
+            raise UsageError(f"Settings field `anonymous`: {value!r} not in {choices}")
         return True
 
     @staticmethod
@@ -1418,12 +1419,12 @@ class Settings:
                 settings["username"] = str(os.getuid())
 
         _executable = (
-            os.environ.get(wandb.env._EXECUTABLE, self._executable)
+            self._executable
+            or os.environ.get(wandb.env._EXECUTABLE)
             or sys.executable
-            or shutil.which("python")
+            or shutil.which("python3")
+            or "python3"
         )
-        if _executable is None or _executable == "":
-            _executable = "python3"
         settings["_executable"] = _executable
 
         settings["docker"] = wandb.env.get_docker(wandb.util.image_id_from_k8s())
