@@ -5,7 +5,6 @@ from .plot import (
     plot_classifier,
     plot_clusterer,
     plot_confusion_matrix,
-    plot_decision_boundaries,
     plot_elbow_curve,
     plot_feature_importances,
     plot_learning_curve,
@@ -30,7 +29,6 @@ __all__ = [
     "plot_roc",
     "plot_precision_recall",
     "plot_confusion_matrix",
-    "plot_decision_boundaries",
     "plot_elbow_curve",
     "plot_silhouette",
     "plot_residuals",
