@@ -3,7 +3,6 @@ from .classifier import calibration_curve as plot_calibration_curve
 from .classifier import class_proportions as plot_class_proportions
 from .classifier import classifier as plot_classifier
 from .classifier import confusion_matrix as plot_confusion_matrix
-from .classifier import decision_boundaries as plot_decision_boundaries
 from .classifier import feature_importances as plot_feature_importances
 from .classifier import precision_recall as plot_precision_recall
 from .classifier import roc as plot_roc
@@ -28,7 +27,6 @@ __all__ = [
     "plot_roc",
     "plot_precision_recall",
     "plot_confusion_matrix",
-    "plot_decision_boundaries",
     "plot_elbow_curve",
     "plot_silhouette",
     "plot_residuals",
